@@ -1,14 +1,10 @@
 from django.conf.urls.defaults import patterns, url
 from django.core.urlresolvers import reverse
 from django.test import TestCase
+from django.utils import simplejson as json
 
 from djangorestframework.resource import Resource
 
-try:
-    import json
-except ImportError:
-    import simplejson as json
-
 
 class MockResource(Resource):
     """Mock resource which simply returns a URL, so that we can ensure that reversed URLs are fully qualified"""
